# Generated by Django 1.11.24 on 2020-03-02 13:10
from __future__ import unicode_literals

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [("portal", "0056_remove_preview_user")]

    operations = [migrations.DeleteModel(name="FrontPageNews")]
