{% extends 'portal/form_shapes.html' %}
{% load static %}
{% load app_tags %}

{% block form_content %}
    <div id="student_login_page"></div>
    <h4 class="center-block">Welcome to class: {{ form.access_code }}</h4>
    <h5>Please enter your login details.</h5>
    <form id="form-login-school" method="post" autocomplete="off">

        {% csrf_token %}

        {{ form.non_field_errors }}

        <div class="form__input">
            {{ form.username }}
            <small>{{ form.username.help_text }}</small>
            {{ form.username.errors }}
        </div>

        <div class="form--row">
            <div class="input--icon">
                {{ form.password }} <span id="password-field-icon" class="iconify" data-icon="material-symbols:visibility-off"></span>
            </div>
            <small>{{ form.password.help_text }}</small>
            {{ form.password.errors }}
        </div>

        <div class="d-flex justify-content-end row">
            <button type="submit" name="school_login" class="button button--primary button--login button-right-arrow">
                Log in</button>
        </div>
    </form>
    <script type="text/javascript" src="{% static 'portal/js/studentLogin.js' %}"></script>
{% endblock form_content %}
