{% if module_name == "default" %}
    <!-- Production Environment -->
    <noscript>
        <iframe
        src="https://www.googletagmanager.com/ns.html?id=GTM-M32M5N5"
        height="0"
        width="0"
        style="display:none;visibility:hidden">
        </iframe>
    </noscript>
{% endif %}
{% if module_name == "staging" %}
    <!-- Staging environment -->
    <noscript>
    <iframe
        src="https://www.googletagmanager.com/ns.html?id=GTM-M32M5N5&gtm_auth=ZZqc7ZNE1mTX6vrV43Q_7g&gtm_preview=env-6&gtm_cookies_win=x"
        height="0"
        width="0"
        style="display:none;visibility:hidden">
    </iframe>
    </noscript>
{% endif %}
