{% extends 'portal/form_shapes.html' %}
{% load static %}
{% load app_tags %}

{% block form_content %}
    <div id="student_login_page_class_code"></div>
    <h4 class="center-block">Welcome</h4>
    <h5>Please enter your class code.</h5>
    <form id="form-login-school-class-code" method="post" autocomplete="off">

        {% csrf_token %}

        {{ form.non_field_errors }}

        <div class="form__input">
            {{ form.access_code }}
            <small>{{ form.access_code.help_text }}</small>
            {{ form.access_code.errors }}
        </div>

        <p class="background text-left"><strong>Forgotten your login details? Please check with your teacher.</strong></p>

        <div class="d-flex justify-content-end row">
            <button type="submit" name="school_login_class_code"
                    class="button button--primary button--login button-right-arrow">Log in</button>
        </div>
    </form>
{% endblock form_content %}
