{% extends 'portal/base.html' %}
{% load static %}
{% load app_tags %}

{% block subNav %}
{% if not onboarding_done %}
<div class="banner banner--teacher">
    <div class="container">
        <div class="row">
            <div class="col-xs-12 flex-column text-center text-lg-left">
                <h1>Welcome, {{ user|make_into_username }}</h1>
                <h5>Everything you need to start coding with your class is here. Let's set you up.</h5>
            </div>
        </div>
    </div>
</div>
{% endif %}
{% endblock subNav %}

{% block content %}
{% endblock content %}
